@@ -31,6 +31,12 @@ has 'command_usage' => (
     lazy_build  => 1,
 );
 
+has 'command_strict' => (
+    is          => 'rw',
+    isa         => 'Bool',
+    default     => 0,
+);
+
 sub command_short_description_predicate {
     my ($self) = @_;  
     return $self->_command_description_predicate('command_short_description');
@@ -59,7 +65,7 @@ sub _build_command_long_description {
 
 sub command_usage_predicate {
     my ($self) = @_;
-    return $self->_command_description_predicate('command_long_description');
+    return $self->_command_description_predicate('command_usage');
 }
 
 sub _build_command_usage {
@@ -129,7 +135,7 @@ MooseX::App::Meta::Role::Class::Command - Meta class role for command classes
 =head1 DESCRIPTION
 
 This meta class role will automatically be applied to all command classes.
-This documentation is only of interest if you intent to write plugins for 
+This documentation is only of interest if you intend to write plugins for 
 MooseX-App.
 
 =head1 ACCESSORS
@@ -137,8 +143,8 @@ MooseX-App.
 =head2 command_short_description
 
 Read/set the short command description. Will be extracted from the Pod NAME
-section if not set. Alternative this will be taken from the DistZilla
-ABSTRACT tag.
+or ABSTRACT section if not set. Alternative this will be taken from the 
+DistZilla ABSTRACT tag.
 
 =head2 command_long_description
 
@@ -151,6 +157,15 @@ Read/set the long command usage. Will be extracted from the Pod
 SYNOPSIS or USAGE section if not set. If these Pod sections are not defined
 the usage will be autogenerated.
 
+=head command_strict
+
+Read/set the strict command flag. If strict is enabled the command will 
+terminate with an error message if superfluous/unknown positional parameters 
+are supplied. If disabled all extra parameters will be copied to the 
+L<extra_argv> attribute.
+
+The app_strict function in the app classes allows to set this option globally.
+
 =head1 METHODS
 
 =head2 _build_command_pod
