@@ -9,6 +9,7 @@ use Moose;
 
 use Encode qw(decode);
 use MooseX::App::ParsedArgv::Element;
+no if $] >= 5.018000, warnings => qw(experimental::smartmatch);
 
 my $SINGLETON;
 
@@ -18,16 +19,17 @@ has 'argv' => (
     lazy_build      => 1,
 );
 
-has 'fuzzy' => (
-    is              => 'rw',
-    isa             => 'Bool',
-);
+#has 'fuzzy' => (
+#    is              => 'rw',
+#    isa             => 'Bool',
+#    required        => 1,
+#);
 
 has 'hints' => (
     is              => 'rw',
     isa             => 'ArrayRef[Str]',
     default         => sub { [] },
-);
+); # Hints for boolean flags
 
 has 'elements' => (
     is              => 'rw',
@@ -109,7 +111,8 @@ sub _build_elements {
                 # Value
                 default {
                     if (defined $lastkey) {
-                        # Is boolean # TODO handle fuzzy
+                        # Is boolean 
+                        # TODO handle fuzzy
                         if ($lastkey->key ~~ $self->hints) {
                             push(@elements,MooseX::App::ParsedArgv::Element->new( key => $element, type => 'parameter' ));
                         # Not a boolean field
@@ -217,7 +220,7 @@ MooseX::App::ParsedArgv - Parses @ARGV
 
 This is a helper class that holds all options parsed from @ARGV. It is 
 implemented as a singleton. Unless you are developing a MooseX::App plugin
-you should not need to interact with this class.
+you usually do not need to interact with this class.
 
 =head1 METHODS
 
@@ -232,19 +235,16 @@ a new one will be created.
 
 =head2 argv
 
-Get/set the original @ARGV. 
-
-Also available via C<new>
+Accessor for the original @ARGV. 
 
 =head2 hints
 
-Sets fuzzy hin 
-
-Also available via C<new>
+Accessor for an array of attributes that tells the parser which attributes
+should be regarded as flags without value.
 
 =head2 first_argv
 
-Shifts the first element from ARGV.
+Shifts the current first element from ARGV.
 
 =head2 available
 
