@@ -7,7 +7,7 @@ use strict;
 use warnings;
 
 use Moose::Exporter;
-use MooseX::App::Exporter qw(app_base app_fuzzy app_strict option parameter command_short_description command_long_description command_usage);
+use MooseX::App::Exporter qw(app_base app_fuzzy app_strict option parameter command_short_description command_long_description command_usage command_strict);
 use MooseX::App::Meta::Role::Attribute::Option;
 use MooseX::App::Message::Envelope;
 use Scalar::Util qw(blessed);
@@ -15,7 +15,7 @@ use Scalar::Util qw(blessed);
 our $VERSION = '1.15';
 
 my ($IMPORT,$UNIMPORT,$INIT_META) = Moose::Exporter->build_import_methods(
-    with_meta           => [ qw(app_base app_fuzzy app_strict option parameter command_short_description command_long_description command_usage) ],
+    with_meta           => [ qw(app_base app_fuzzy app_strict option parameter command_short_description command_long_description command_usage command_strict) ],
     also                => [ 'Moose' ],
     as_is               => [ 'new_with_options' ],
     install             => [ 'unimport', 'init_meta' ],
@@ -73,8 +73,10 @@ sub new_with_options {
     }
     
     # Get ARGV
-    my $parsed_argv = MooseX::App::ParsedArgv->new();
-    $parsed_argv->argv(\@ARGV);
+    my $parsed_argv = MooseX::App::ParsedArgv->new(
+        argv        => \@ARGV,
+        fuzzy       => $class->meta->app_fuzzy,
+    );
 
     return $class->initialize_command_class($class,%args);
 }
