@@ -4,6 +4,7 @@ use 5.010;
 use utf8;
 use strict;
 use warnings;
+no if $] >= 5.018000, warnings => qw/ experimental::smartmatch /;
 
 use List::Util qw(max);
 
@@ -93,7 +94,7 @@ sub split_string {
     return @lines;
 }
 
-sub parse_pod {
+sub package_to_filename {
     my ($package) = @_;
     
     # Package to filename
@@ -101,6 +102,7 @@ sub parse_pod {
     $package_filename =~ s/::/\//g;
     $package_filename .= '.pm';
     
+    
     my $package_filepath;
     if (defined $INC{$package_filename}) {
         $package_filepath = $INC{$package_filename};
@@ -112,6 +114,16 @@ sub parse_pod {
         unless defined $package_filepath
         && -e $package_filepath;
     
+    return $package_filepath;
+}
+
+sub parse_pod {
+    my ($package) = @_;
+    
+    my $package_filepath = package_to_filename($package);
+    return
+        unless $package_filepath;
+    
     # Parse pod
     my $document = Pod::Elemental->read_file($package_filepath);
     
